@@ -85,8 +85,10 @@ class IncomingMailProcessor(Thread):
                             msg['Message-Id'], box )
                             
                 else:
+		    self.log.info(
+	                "Message '%s' from inbox 'r' processed.",
+			msg['Message-Id'], box )
                     transaction.commit()
-
                 
             else:
                 if forever:
